@@ -387,7 +387,7 @@ class TPsimplex:
             f=[self.main_matrix[0][i]  for i in range(len(self.main_matrix[0])-1)]
 
             for i in f:
-                if i>0:
+                if i>1e-05:
                     return False
             return True
         elif type=='min':
@@ -412,13 +412,13 @@ class TPsimplex:
         f=[]
         self.entering_indx=None
         if type=='1_phase':
-            max = 0
+            max = 1e-05
             for i,v in enumerate(matrix):
                 if i<len(self.coeff_of_var[0]):
                     f.append(v)
 
             for i,v in enumerate(f):
-                if v >max :
+                if v >max:
                     max=v
                     self.entering_indx=i
         elif type=='max':
@@ -534,7 +534,7 @@ class TPsimplex:
         temp_list2=[]
         if(self.leaving_indx==None):
             self.error=True
-            self.msg="\nUnbounded solution found!"
+            self.msg="\nUnbounded solution found! {}"
             return False
 
         if (self.entering_indx == None):
@@ -659,7 +659,7 @@ class TPsimplex:
 
         if self.error==False:
             ln=len(self.main_matrix[0])-1
-            if self.main_matrix[0][ln]>0:
+            if self.main_matrix[0][ln]>=0:
                 print("\n\n\nSOLUTION\n")
                 self.__print_matrix(msg='SOLUTION')
                 final_solution=[['F',round(self.main_matrix[0][ln],3)]]
